@@ -46,8 +46,8 @@ class GotoOffsetView : public AbstractToolWidget
   Q_OBJECT
 
   public:
-    explicit GotoOffsetView( GotoOffsetTool* tool, QWidget* parent = 0 );
-    virtual ~GotoOffsetView();
+    explicit GotoOffsetView( GotoOffsetTool* tool, QWidget* parent = nullptr );
+    ~GotoOffsetView() override;
 
   public:
     GotoOffsetTool* tool() const;
