@@ -41,10 +41,10 @@ DataInformation* toDataInformation(const QScriptValue& value, const ParserInfo&
     if (!value.isValid())
     {
         oldInfo.error() << "invalid value passed!";
-        return 0;
+        return nullptr;
     }
     ParserInfo info(oldInfo);
-    QString nameOverride = value.property(PROPERTY_NAME).toString();
+    QString nameOverride = value.property(PROPERTY_NAME()).toString();
     if (!nameOverride.isEmpty())
         info.name = nameOverride;
 
@@ -53,27 +53,27 @@ DataInformation* toDataInformation(const QScriptValue& value, const ParserInfo&
     {
         //apparently regexp is a function
         info.error() << "Cannot convert a RegExp object to DataInformation!";
-        return 0;
+        return nullptr;
     }
     if (value.isFunction())
     {
         info.error() << "Cannot convert a Function object to DataInformation!";
-        return 0;
+        return nullptr;
     }
     if (value.isArray())
     {
         info.error() << "Cannot convert a Array object to DataInformation!";
-        return 0;
+        return nullptr;
     }
     if (value.isDate())
     {
         info.error() << "Cannot convert a Date object to DataInformation!";
-        return 0;
+        return nullptr;
     }
     if (value.isError())
     {
         info.error() << "Cannot convert a Error object to DataInformation!";
-        return 0;
+        return nullptr;
     }
     //variant and qobject are also object types, however they cannot appear from user code, no need to check
 
@@ -94,45 +94,45 @@ DataInformation* toDataInformation(const QScriptValue& value, const ParserInfo&
         else
             info.error() << "Cannot convert object of unknown type to DataInformation!";
 
-        return 0; //no point trying to convert
+        return nullptr; //no point trying to convert
     }
 
-    QString type = value.property(PROPERTY_INTERNAL_TYPE).toString();
+    QString type = value.property(PROPERTY_INTERNAL_TYPE()).toString();
     if (type.isEmpty())
     {
         info.error() << "Cannot convert object since type of object could not be determined!";
-        return 0;
+        return nullptr;
     }
-    DataInformation* returnVal = 0;
+    DataInformation* returnVal = nullptr;
 
-    if (type == TYPE_ARRAY)
+    if (type == TYPE_ARRAY())
         returnVal = toArray(value, info);
 
-    else if (type == TYPE_STRUCT)
+    else if (type == TYPE_STRUCT())
         returnVal = toStruct(value, info);
 
-    else if (type == TYPE_UNION)
+    else if (type == TYPE_UNION())
         returnVal = toUnion(value, info);
 
-    else if (type == TYPE_BITFIELD)
+    else if (type == TYPE_BITFIELD())
         returnVal = toBitfield(value, info);
 
-    else if (type == TYPE_ENUM)
+    else if (type == TYPE_ENUM())
         returnVal = toEnum(value, false, info);
 
-    else if (type == TYPE_FLAGS)
+    else if (type == TYPE_FLAGS())
         returnVal = toEnum(value, true, info);
 
-    else if (type == TYPE_STRING)
+    else if (type == TYPE_STRING())
         returnVal = toString(value, info);
 
-    else if (type == TYPE_POINTER)
+    else if (type == TYPE_POINTER())
         returnVal = toPointer(value, info);
 
-    else if (type == TYPE_TAGGED_UNION)
+    else if (type == TYPE_TAGGED_UNION())
         returnVal = toTaggedUnion(value, info);
 
-    else if (type == TYPE_PRIMITIVE)
+    else if (type == TYPE_PRIMITIVE())
         returnVal = toPrimitive(value, info);
 
     else
@@ -141,18 +141,18 @@ DataInformation* toDataInformation(const QScriptValue& value, const ParserInfo&
     if (returnVal)
     {
         CommonParsedData cpd(info);
-        QString byteOrderStr = value.property(PROPERTY_BYTEORDER).toString();
+        QString byteOrderStr = value.property(PROPERTY_BYTEORDER()).toString();
         if (!byteOrderStr.isEmpty())
             cpd.endianess = ParserUtils::byteOrderFromString(byteOrderStr,
                     LoggerWithContext(info.logger, info.context()));
-        cpd.updateFunc = value.property(PROPERTY_UPDATE_FUNC);
-        cpd.validationFunc = value.property(PROPERTY_VALIDATION_FUNC);
-        cpd.toStringFunc = value.property(PROPERTY_TO_STRING_FUNC);
-        cpd.customTypeName = value.property(PROPERTY_CUSTOM_TYPE_NAME).toString();
+        cpd.updateFunc = value.property(PROPERTY_UPDATE_FUNC());
+        cpd.validationFunc = value.property(PROPERTY_VALIDATION_FUNC());
+        cpd.toStringFunc = value.property(PROPERTY_TO_STRING_FUNC());
+        cpd.customTypeName = value.property(PROPERTY_CUSTOM_TYPE_NAME()).toString();
         if (!DataInformationFactory::commonInitialization(returnVal, cpd))
         {
             delete returnVal; //error message has already been logged
-            return 0;
+            return nullptr;
         }
     }
     return returnVal;
@@ -161,10 +161,10 @@ DataInformation* toDataInformation(const QScriptValue& value, const ParserInfo&
 ArrayDataInformation* toArray(const QScriptValue& value, const ParserInfo& info)
 {
     ArrayParsedData apd(info);
-    apd.length = value.property(PROPERTY_LENGTH);
-    QScriptValue childType = value.property(PROPERTY_TYPE);
+    apd.length = value.property(PROPERTY_LENGTH());
+    QScriptValue childType = value.property(PROPERTY_TYPE());
     ParserInfo childInfo(info);
-    DummyDataInformation dummy(info.parent, info.name + QLatin1Char('.') + NAME_ARRAY_TYPE);
+    DummyDataInformation dummy(info.parent, info.name + QLatin1Char('.') + NAME_ARRAY_TYPE());
     childInfo.parent = &dummy;
     apd.arrayType = toDataInformation(childType, childInfo);
 
@@ -174,29 +174,29 @@ ArrayDataInformation* toArray(const QScriptValue& value, const ParserInfo& info)
 AbstractBitfieldDataInformation* toBitfield(const QScriptValue& value, const ParserInfo& info)
 {
     BitfieldParsedData bpd(info);
-    bpd.type = value.property(PROPERTY_TYPE).toString();
-    bpd.width = ParserUtils::intFromScriptValue(value.property(PROPERTY_WIDTH));
+    bpd.type = value.property(PROPERTY_TYPE()).toString();
+    bpd.width = ParserUtils::intFromScriptValue(value.property(PROPERTY_WIDTH()));
     return DataInformationFactory::newBitfield(bpd);
 }
 
 PrimitiveDataInformation* toPrimitive(const QScriptValue& value, const ParserInfo& info)
 {
     PrimitiveParsedData ppd(info);
-    ppd.type = value.isString() ? value.toString() : value.property(PROPERTY_TYPE).toString();
+    ppd.type = value.isString() ? value.toString() : value.property(PROPERTY_TYPE()).toString();
     return DataInformationFactory::newPrimitive(ppd);
 }
 
 StructureDataInformation* toStruct(const QScriptValue& value, const ParserInfo& info)
 {
     StructOrUnionParsedData supd(info);
-    supd.children.reset(new ScriptValueChildrenParser(info, value.property(PROPERTY_CHILDREN)));
+    supd.children.reset(new ScriptValueChildrenParser(info, value.property(PROPERTY_CHILDREN())));
     return DataInformationFactory::newStruct(supd);
 }
 
 UnionDataInformation* toUnion(const QScriptValue& value, const ParserInfo& info)
 {
     StructOrUnionParsedData supd(info);
-    supd.children.reset(new ScriptValueChildrenParser(info, value.property(PROPERTY_CHILDREN)));
+    supd.children.reset(new ScriptValueChildrenParser(info, value.property(PROPERTY_CHILDREN())));
     return DataInformationFactory::newUnion(supd);}
 
 PointerDataInformation* toPointer(const QScriptValue& value, const ParserInfo& info)
@@ -206,10 +206,10 @@ PointerDataInformation* toPointer(const QScriptValue& value, const ParserInfo& i
     ParserInfo childInfo(info);
     DummyDataInformation dummy(info.parent, info.name);
     childInfo.parent = &dummy;
-    childInfo.name = NAME_POINTER_TARGET;
-    ppd.pointerTarget = toDataInformation(value.property(PROPERTY_TARGET), childInfo);
-    childInfo.name = NAME_POINTER_VALUE_TYPE;
-    ppd.valueType = toDataInformation(value.property(PROPERTY_TYPE), childInfo);
+    childInfo.name = NAME_POINTER_TARGET();
+    ppd.pointerTarget = toDataInformation(value.property(PROPERTY_TARGET()), childInfo);
+    childInfo.name = NAME_POINTER_VALUE_TYPE();
+    ppd.valueType = toDataInformation(value.property(PROPERTY_TYPE()), childInfo);
 
     return DataInformationFactory::newPointer(ppd);
 }
@@ -217,14 +217,14 @@ PointerDataInformation* toPointer(const QScriptValue& value, const ParserInfo& i
 EnumDataInformation* toEnum(const QScriptValue& value, bool flags, const ParserInfo& info)
 {
     EnumParsedData epd(info);
-    QScriptValue enumType = value.property(PROPERTY_TYPE);
+    QScriptValue enumType = value.property(PROPERTY_TYPE());
     if (enumType.isString())
         epd.type = enumType.toString();
     else if (enumType.isObject())
-        epd.type = enumType.property(PROPERTY_TYPE).toString();
+        epd.type = enumType.property(PROPERTY_TYPE()).toString();
     //else it stays empty
-    epd.enumName = value.property(PROPERTY_ENUM_NAME).toString();
-    epd.enumValuesObject = value.property(PROPERTY_ENUM_VALUES);
+    epd.enumName = value.property(PROPERTY_ENUM_NAME()).toString();
+    epd.enumValuesObject = value.property(PROPERTY_ENUM_VALUES());
 
     if (flags)
         return DataInformationFactory::newFlags(epd);
@@ -236,35 +236,35 @@ EnumDataInformation* toEnum(const QScriptValue& value, bool flags, const ParserI
 StringDataInformation* toString(const QScriptValue& value, const ParserInfo& info)
 {
     StringParsedData spd(info);
-    spd.encoding = value.property(PROPERTY_ENCODING).toString();
-    spd.termination = ParserUtils::uintFromScriptValue(value.property(PROPERTY_TERMINATED_BY));
-    spd.maxByteCount = ParserUtils::uintFromScriptValue(value.property(PROPERTY_MAX_BYTE_COUNT));
-    spd.maxCharCount = ParserUtils::uintFromScriptValue(value.property(PROPERTY_MAX_CHAR_COUNT));
+    spd.encoding = value.property(PROPERTY_ENCODING()).toString();
+    spd.termination = ParserUtils::uintFromScriptValue(value.property(PROPERTY_TERMINATED_BY()));
+    spd.maxByteCount = ParserUtils::uintFromScriptValue(value.property(PROPERTY_MAX_BYTE_COUNT()));
+    spd.maxCharCount = ParserUtils::uintFromScriptValue(value.property(PROPERTY_MAX_CHAR_COUNT()));
     return DataInformationFactory::newString(spd);
 }
 
 TaggedUnionDataInformation* toTaggedUnion(const QScriptValue& value, const ParserInfo& info)
 {
     TaggedUnionParsedData tpd(info);
-    QScriptValue alternatives = value.property(PROPERTY_ALTERNATIVES);
+    QScriptValue alternatives = value.property(PROPERTY_ALTERNATIVES());
     if (!alternatives.isArray())
     {
         info.error() << "Alternatives must be an array!";
-        return 0;
+        return nullptr;
     }
-    int length = alternatives.property(PROPERTY_LENGTH).toInt32();
+    int length = alternatives.property(PROPERTY_LENGTH()).toInt32();
     for (int i = 0; i < length; ++i)
     {
         TaggedUnionParsedData::Alternatives alt;
         QScriptValue current = alternatives.property(i);
-        alt.name = current.property(PROPERTY_STRUCT_NAME).toString();
-        alt.selectIf = current.property(PROPERTY_SELECT_IF);
+        alt.name = current.property(PROPERTY_STRUCT_NAME()).toString();
+        alt.selectIf = current.property(PROPERTY_SELECT_IF());
         alt.fields = QSharedPointer<ChildrenParser>(
-                new ScriptValueChildrenParser(info, current.property(PROPERTY_CHILDREN)));
+                new ScriptValueChildrenParser(info, current.property(PROPERTY_CHILDREN())));
         tpd.alternatives.append(alt);
     }
-    tpd.children.reset(new ScriptValueChildrenParser(info, value.property(PROPERTY_CHILDREN)));
-    tpd.defaultFields.reset(new ScriptValueChildrenParser(info, value.property(PROPERTY_DEFAULT_CHILDREN)));
+    tpd.children.reset(new ScriptValueChildrenParser(info, value.property(PROPERTY_CHILDREN())));
+    tpd.defaultFields.reset(new ScriptValueChildrenParser(info, value.property(PROPERTY_DEFAULT_CHILDREN())));
     return DataInformationFactory::newTaggedUnion(tpd);
 }
 
@@ -283,7 +283,7 @@ DataInformation* ScriptValueConverter::ScriptValueChildrenParser::next()
 {
     Q_ASSERT(hasNext());
     mIter.next();
-    if (mValue.isArray() && mIter.name() == QStringLiteral("length"))
+    if (mValue.isArray() && mIter.name() == QLatin1String("length"))
         mIter.next(); //skip length property
     mInfo.name = mIter.name();
     return toDataInformation(mIter.value(), mInfo);
@@ -297,7 +297,7 @@ bool ScriptValueConverter::ScriptValueChildrenParser::hasNext()
     {
         //check if next element is length property
         mIter.next();
-        if (mIter.name() != QStringLiteral("length"))
+        if (mIter.name() != QLatin1String("length"))
         {
             mIter.previous(); //go back and return true
             return true;
