@@ -34,8 +34,8 @@ class ScriptLoggerView : public QWidget
 Q_OBJECT
     Q_DISABLE_COPY(ScriptLoggerView)
 public:
-    explicit ScriptLoggerView(const TopLevelDataInformation::List& data, QWidget* parent = 0);
-    virtual ~ScriptLoggerView();
+    explicit ScriptLoggerView(const TopLevelDataInformation::List& data, QWidget* parent = nullptr);
+    ~ScriptLoggerView() override;
 
 protected Q_SLOTS:
     void updateModel(int index);
