@@ -40,11 +40,11 @@ class ByteArrayValuesStreamEncoderConfigEditor : public AbstractModelStreamEncod
   Q_OBJECT
 
   public:
-    explicit ByteArrayValuesStreamEncoderConfigEditor( ByteArrayValuesStreamEncoder* encoder, QWidget* parent = 0 );
-    virtual ~ByteArrayValuesStreamEncoderConfigEditor();
+    explicit ByteArrayValuesStreamEncoderConfigEditor( ByteArrayValuesStreamEncoder* encoder, QWidget* parent = nullptr );
+    ~ByteArrayValuesStreamEncoderConfigEditor() override;
 
   public: // AbstractModelStreamEncoderConfigEditor API
-    virtual AbstractSelectionView* createPreviewView() const;
+    AbstractSelectionView* createPreviewView() const override;
 
   protected Q_SLOTS:
     void onSettingsChanged();
