@@ -31,6 +31,7 @@
 #include <KStandardAction>
 #include <KXMLGUIClient>
 #include <KLocalizedString>
+#include <kcoreaddons_version.h>
 // Qt
 #include <QAction>
 
@@ -43,13 +44,15 @@ CloseController::CloseController( AbstractDocumentStrategy* documentStrategy,
                                   bool supportMultiple )
   : AbstractXmlGuiController()
   , mDocumentStrategy( documentStrategy )
-  , mDocument( 0 )
+  , mDocument( nullptr )
 {
     KActionCollection* actionCollection = guiClient->actionCollection();
 
     const QIcon documentCloseIcon = QIcon::fromTheme( QStringLiteral("document-close") );
     mCloseAction  = KStandardAction::close(  this, SLOT(close()),  actionCollection );
+#if KCOREADDONS_VERSION < 0x053800
     mCloseAction->setIcon( documentCloseIcon );
+#endif
     mCloseAction->setEnabled( false );
 
     if( supportMultiple )
@@ -66,17 +69,17 @@ CloseController::CloseController( AbstractDocumentStrategy* documentStrategy,
         mCloseAllOtherAction->setIcon( documentCloseIcon );
         mCloseAllOtherAction->setEnabled( false );
 
-        connect( mDocumentStrategy, SIGNAL(added(QList<Kasten::AbstractDocument*>)),
-                SLOT(onDocumentsChanged()) );
-        connect( mDocumentStrategy, SIGNAL(closing(QList<Kasten::AbstractDocument*>)),
-                SLOT(onDocumentsChanged()) );
+        connect( mDocumentStrategy, &Kasten::AbstractDocumentStrategy::added,
+                 this, &CloseController::onDocumentsChanged );
+        connect( mDocumentStrategy, &Kasten::AbstractDocumentStrategy::closing,
+                 this, &CloseController::onDocumentsChanged );
     }
 }
 
 void CloseController::setTargetModel( AbstractModel* model )
 {
-    mDocument = model ? model->findBaseModel<AbstractDocument*>() : 0;
-    const bool hasDocument = ( mDocument != 0 );
+    mDocument = model ? model->findBaseModel<AbstractDocument*>() : nullptr;
+    const bool hasDocument = ( mDocument != nullptr );
 
     mCloseAction->setEnabled( hasDocument );
 }
