@@ -33,14 +33,14 @@ namespace Kasten
 {
 
 DocumentsTool::DocumentsTool( DocumentManager* documentManager )
- : mDocumentManager( documentManager ), mFocussedDocument( 0 )
+ : mDocumentManager( documentManager ), mFocussedDocument( nullptr )
 {
     setObjectName( QStringLiteral( "Documents" ) );
 
-    connect( mDocumentManager, SIGNAL(added(QList<Kasten::AbstractDocument*>)),
-             SIGNAL(documentsAdded(QList<Kasten::AbstractDocument*>)) );
-    connect( mDocumentManager, SIGNAL(closing(QList<Kasten::AbstractDocument*>)),
-             SIGNAL(documentsClosing(QList<Kasten::AbstractDocument*>)) );
+    connect( mDocumentManager, &DocumentManager::added,
+             this, &DocumentsTool::documentsAdded );
+    connect( mDocumentManager, &DocumentManager::closing,
+             this, &DocumentsTool::documentsClosing );
 }
 
 QList<AbstractDocument*> DocumentsTool::documents() const { return mDocumentManager->documents(); }
@@ -50,7 +50,7 @@ QString DocumentsTool::title() const { return i18nc("@title:window", "Documents"
 // TODO: this is an abuse of setTargetModel. Find other way to get focused model
 void DocumentsTool::setTargetModel( AbstractModel* model )
 {
-    mFocussedDocument = model ? model->findBaseModel<AbstractDocument*>() : 0;
+    mFocussedDocument = model ? model->findBaseModel<AbstractDocument*>() : nullptr;
     emit focussedDocumentChanged( mFocussedDocument );
 }
 
