@@ -24,9 +24,9 @@
 #define VIEWLISTMENUCONTROLLER_H
 
 // lib
-#include "kastencontrollers_export.h"
+#include <kasten/kastencontrollers_export.h>
 // Kasten gui
-#include <abstractxmlguicontroller.h>
+#include <kasten/abstractxmlguicontroller.h>
 
 class QAction;
 class QActionGroup;
@@ -48,7 +48,7 @@ class KASTENCONTROLLERS_EXPORT ViewListMenuController : public AbstractXmlGuiCon
     ViewListMenuController( ViewManager* viewManager, AbstractGroupedViews* groupedViews, KXMLGUIClient* guiClient );
 
   public: // AbstractXmlGuiController API
-    virtual void setTargetModel( AbstractModel* model );
+    void setTargetModel( AbstractModel* model ) override;
 
   private Q_SLOTS:
     void updateActions();
