@@ -26,23 +26,23 @@
 // library
 #include "abstractfilesystemsyncfromremotejob.h"
 #include <abstractsyncfromremotejob_p.h>
-// KDE
-#include <KTemporaryFile>
+// KF5
+#include <QTemporaryFile>
 
 
-namespace Kasten2
+namespace Kasten
 {
 
 class AbstractModelFileSystemSynchronizer;
 
 
-class KASTENCORE_EXPORT AbstractFileSystemSyncFromRemoteJobPrivate : public AbstractSyncFromRemoteJobPrivate
+class AbstractFileSystemSyncFromRemoteJobPrivate : public AbstractSyncFromRemoteJobPrivate
 {
   public:
     AbstractFileSystemSyncFromRemoteJobPrivate( AbstractFileSystemSyncFromRemoteJob* parent,
                                                 AbstractModelFileSystemSynchronizer* synchronizer );
 
-    virtual ~AbstractFileSystemSyncFromRemoteJobPrivate();
+    ~AbstractFileSystemSyncFromRemoteJobPrivate() override;
 
   public: // KJob API
     void start();
@@ -62,6 +62,7 @@ class KASTENCORE_EXPORT AbstractFileSystemSyncFromRemoteJobPrivate : public Abst
   protected:
     AbstractModelFileSystemSynchronizer* mSynchronizer;
     QString mWorkFilePath;
+    QString mTempFilePath;
     QFile* mFile;
 };
 
@@ -70,7 +71,7 @@ inline AbstractFileSystemSyncFromRemoteJobPrivate::AbstractFileSystemSyncFromRem
     AbstractModelFileSystemSynchronizer* synchronizer )
   : AbstractSyncFromRemoteJobPrivate( parent ),
     mSynchronizer( synchronizer ),
-    mFile( 0 )
+    mFile( nullptr )
 {
 }
 
