@@ -38,7 +38,7 @@ namespace Kasten
 
 TabbedViewsPrivate::TabbedViewsPrivate( TabbedViews* parent )
   : AbstractGroupedViewsPrivate( parent ),
-    mCurrentView( 0 )
+    mCurrentView( nullptr )
 {
 }
 
@@ -51,8 +51,10 @@ void TabbedViewsPrivate::init()
     mTabWidget->setDocumentMode( true );
     mViewAreaBox = new ViewAreaBox( mTabWidget );
 
-    q->connect( mTabWidget, SIGNAL(tabCloseRequested(int)), SLOT(onTabCloseRequest(int)) );
-    q->connect( mTabWidget, SIGNAL(currentChanged(int)), SLOT(onCurrentChanged(int)) );
+    QObject::connect( mTabWidget, &QTabWidget::tabCloseRequested,
+                      q, [&]( int index ) { onTabCloseRequest( index ); } );
+    QObject::connect( mTabWidget, &QTabWidget::currentChanged,
+                      q, [&]( int index ) { onCurrentChanged( index ); } );
 // TODO: restore
 //     q->connect( mTabWidget, SIGNAL(mouseMiddleClick(QWidget*)), SLOT(onCloseRequest(QWidget*)) );
 //     q->connect( mTabWidget, SIGNAL(mouseMiddleClick()), SLOT(onMouseMiddleClick()) );
@@ -67,6 +69,7 @@ QList<AbstractView*> TabbedViewsPrivate::viewList() const
     QList<AbstractView*> result;
 
     const int count = mTabWidget->count();
+    result.reserve(count);
     for( int i=0; i<count; ++i )
     {
         const ViewBox* viewBox = static_cast<const ViewBox*>( mTabWidget->widget(i) );
@@ -106,7 +109,8 @@ void TabbedViewsPrivate::addViews( const QList<AbstractView*>& views )
     int insertIndex = mTabWidget->currentIndex() + 1;
     foreach( AbstractView* view, views )
     {
-        q->connect( view, SIGNAL(titleChanged(QString)), SLOT(onTitleChanged(QString)) );
+        QObject::connect( view, &AbstractModel::titleChanged,
+                          q, [&]( const QString& title ) { onTitleChanged( title ); } );
 
         ViewBox* viewBox = new ViewBox( view, mTabWidget );
         mTabWidget->insertTab( insertIndex, viewBox, view->title() );
@@ -159,12 +163,12 @@ void TabbedViewsPrivate::setCurrentToolInlineView( AbstractToolInlineView* view
     ToolInlineViewWidget* currentViewWidget =
         qobject_cast<ToolInlineViewWidget*>( mViewAreaBox->bottomWidget() );
     AbstractToolInlineView* currentToolInlineView =
-        currentViewWidget ? currentViewWidget->view() : 0;
+        currentViewWidget ? currentViewWidget->view() : nullptr;
 
     if( currentToolInlineView != view )
     {
         ToolInlineViewWidget* toolInlineViewWidget =
-            view ? new ToolInlineViewWidget( view/*->widget()*/ ) : 0;
+            view ? new ToolInlineViewWidget( view/*->widget()*/ ) : nullptr;
         mViewAreaBox->setBottomWidget( toolInlineViewWidget );
     }
 
@@ -181,12 +185,12 @@ void TabbedViewsPrivate::onCurrentChanged( int index )
     Q_Q( TabbedViews );
 
     const ViewBox* viewBox = static_cast<const ViewBox*>( mTabWidget->widget(index) );
-    AbstractView* view = viewBox ? viewBox->view() : 0;
+    AbstractView* view = viewBox ? viewBox->view() : nullptr;
 
     if( view == mCurrentView )
         return;
 
-    mViewAreaBox->setBottomWidget( 0 );
+    mViewAreaBox->setBottomWidget( nullptr );
 
     if( mCurrentView )
         mCurrentView->disconnect( q );
@@ -195,7 +199,8 @@ void TabbedViewsPrivate::onCurrentChanged( int index )
 
     if( view )
     {
-        q->connect( view, SIGNAL(focusChanged(bool)), SLOT(onViewFocusChanged(bool)) );
+        QObject::connect( view, &AbstractView::focusChanged,
+                          q, [&]( bool hasFocus ) { onViewFocusChanged( hasFocus ); } );
         view->widget()->setFocus();
     }
 
